==> libreoffice-fresh-sdk-25.8.4-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "LibreOffice", "index.html", [
    [ "SAL debug areas", "a02539.html", [
      [ "SAL", "a02539.html#SAL", null ],
      [ "basctl", "a02539.html#basctl", null ],
      [ "basic", "a02539.html#basic", null ],
      [ "bridges", "a02539.html#bridges", null ],
      [ "canvas", "a02539.html#canvas", null ],
      [ "chart2", "a02539.html#chart2", null ],
      [ "connectivity", "a02539.html#connectivity", null ],
      [ "comphelper", "a02539.html#comphelper", null ],
      [ "cppu", "a02539.html#cppu", null ],
      [ "cppuhelper", "a02539.html#cppuhelper", null ],
      [ "cpputools", "a02539.html#cpputools", null ],
      [ "cui", "a02539.html#cui", null ],
      [ "drawinglayer", "a02539.html#drawinglayer", null ],
      [ "emfio", "a02539.html#emfio", null ],
      [ "Calc", "a02539.html#Calc", null ],
      [ "desktop", "a02539.html#desktop", null ],
      [ "Draw", "a02539.html#Draw", null ],
      [ "editeng", "a02539.html#editeng", null ],
      [ "embeddedobj", "a02539.html#embeddedobj", null ],
      [ "embedserv", "a02539.html#embedserv", null ],
      [ "extensions", "a02539.html#extensions", null ],
      [ "Filter", "a02539.html#Filter", null ],
      [ "oox", "a02539.html#oox", null ],
      [ "forms", "a02539.html#forms", null ],
      [ "formula", "a02539.html#formula", null ],
      [ "fpicker", "a02539.html#fpicker", null ],
      [ "framework", "a02539.html#framework", null ],
      [ "i18nlangtag", "a02539.html#i18nlangtag", null ],
      [ "i18npool", "a02539.html#i18npool", null ],
      [ "i18n", "a02539.html#i18n", null ],
      [ "io", "a02539.html#io", null ],
      [ "jvmfwk", "a02539.html#jvmfwk", null ],
      [ "LanguageTool", "a02539.html#LanguageTool", null ],
      [ "LibreOfficeKit", "a02539.html#LibreOfficeKit", null ],
      [ "l10ntools", "a02539.html#l10ntools", null ],
      [ "Math", "a02539.html#Math", null ],
      [ "package", "a02539.html#package", null ],
      [ "pyuno", "a02539.html#pyuno", null ],
      [ "sdext", "a02539.html#sdext", null ],
      [ "sfx", "a02539.html#sfx", null ],
      [ "slideshow", "a02539.html#slideshow", null ],
      [ "sot", "a02539.html#sot", null ],
      [ "svl", "a02539.html#svl", null ],
      [ "svtools", "a02539.html#svtools", null ],
      [ "svx", "a02539.html#svx", null ],
      [ "toolkit", "a02539.html#toolkit", null ],
      [ "tools", "a02539.html#tools", null ],
      [ "ucb", "a02539.html#ucb", null ],
      [ "unotools", "a02539.html#unotools", null ],
      [ "URE", "a02539.html#URE", null ],
      [ "sax", "a02539.html#sax", null ],
      [ "stoc", "a02539.html#stoc", null ],
      [ "VCL", "a02539.html#VCL", null ],
      [ "winaccessibility", "a02539.html#winaccessibility", null ],
      [ "Writer", "a02539.html#Writer", null ],
      [ "writerfilter", "a02539.html#writerfilter", null ],
      [ "writerperfect", "a02539.html#writerperfect", null ],
      [ "xmloff", "a02539.html#xmloff", null ],
      [ "xmlsecurity", "a02539.html#xmlsecurity", null ],
      [ "xmlscript", "a02539.html#xmlscript", null ],
      [ "dbaccess", "a02539.html#dbaccess", null ],
      [ "avmedia", "a02539.html#avmedia", null ],
      [ "other", "a02539.html#other", null ]
    ] ],
    [ "Basic logging functionality.", "a02540.html", null ],
    [ "Deprecated List", "a00518.html", null ],
    [ "Todo List", "a00519.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"a00008.html",
"a00083.html#ad81bc3680b7f99be0a1a1482a38e533c",
"a00125.html",
"a00152.html#ab7f49d173ed996548a2185a7aace26d9",
"a00188.html#abff7d95dcd969cbdf1ec32c800faffcb",
"a00236.html#a026df9a7dc5a3644a22d575407836263a05470b4467b01d015082c4d7505858f1",
"a00287.html#a26ca5ffc96b32c3be3b42ef51436b17f",
"a00515.html#ac3f10d1dde9a631a2df769c9eefd1fd3",
"a00537.html#a36808dda29a2ec49670b0b872e75fa13",
"a00606.html",
"a00662.html#ad74a3c73403419e46c7a92870f7e9b10",
"a00734.html#aed0b013ab18b23707b7b2788ef4fdd5e",
"a00754.html#a6622d70ef347f46d155b4a49bf68752c",
"a00774.html#ae2e12b95c2df5b6cab62104982151c7eaca7db22a5e31421a7e2306060167f419",
"a00818.html#a10b27a9d38e4e5c73c477259202cd4fe",
"a00858.html#ac85ef2864e747240e53f3db9df1ec4c3",
"a00954.html#a2cf4f115042fda34f5edb545a8e96878",
"a01010.html#a56de184bc83af0a21d396de4c54f405a",
"a01098.html#adbc203e7235e02bf44917c243de7b126",
"a01218.html#adaaa168244b4bad4afb2a90d090a0cef",
"a01338.html",
"a01442.html#aad0b4c56e092bbc1a45ca7d14a2a9b23",
"a01554.html#ae8127f1b5406ffbc976ca7a5cd9283b1",
"a01674.html#a2b55425d3c8e0fac91bab01a7a9d12df",
"a01778.html#adb6444322d514f4cb23a4afd52df2605",
"a01874.html#a80a384915e2985753f7bdbb1c9195faa",
"a01930.html#ab3eaf4a3b6d6e699c6feb2820069c0ff",
"a02539.html#URE",
"globals_func_s.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';

==> libreoffice-fresh-sdk-26.2.1-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/cpp/ref/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "LibreOffice", "index.html", [
    [ "SAL debug areas", "a02539.html", [
      [ "SAL", "a02539.html#SAL", null ],
      [ "basctl", "a02539.html#basctl", null ],
      [ "basic", "a02539.html#basic", null ],
      [ "bridges", "a02539.html#bridges", null ],
      [ "canvas", "a02539.html#canvas", null ],
      [ "chart2", "a02539.html#chart2", null ],
      [ "codemaker", "a02539.html#codemaker", null ],
      [ "connectivity", "a02539.html#connectivity", null ],
      [ "comphelper", "a02539.html#comphelper", null ],
      [ "cppu", "a02539.html#cppu", null ],
      [ "cppuhelper", "a02539.html#cppuhelper", null ],
      [ "cpputools", "a02539.html#cpputools", null ],
      [ "cui", "a02539.html#cui", null ],
      [ "drawinglayer", "a02539.html#drawinglayer", null ],
      [ "emfio", "a02539.html#emfio", null ],
      [ "Calc", "a02539.html#Calc", null ],
      [ "desktop", "a02539.html#desktop", null ],
      [ "Draw", "a02539.html#Draw", null ],
      [ "editeng", "a02539.html#editeng", null ],
      [ "embeddedobj", "a02539.html#embeddedobj", null ],
      [ "embedserv", "a02539.html#embedserv", null ],
      [ "extensions", "a02539.html#extensions", null ],
      [ "Filter", "a02539.html#Filter", null ],
      [ "oox", "a02539.html#oox", null ],
      [ "forms", "a02539.html#forms", null ],
      [ "formula", "a02539.html#formula", null ],
      [ "fpicker", "a02539.html#fpicker", null ],
      [ "framework", "a02539.html#framework", null ],
      [ "i18nlangtag", "a02539.html#i18nlangtag", null ],
      [ "i18npool", "a02539.html#i18npool", null ],
      [ "i18n", "a02539.html#i18n", null ],
      [ "io", "a02539.html#io", null ],
      [ "jvmfwk", "a02539.html#jvmfwk", null ],
      [ "LanguageTool", "a02539.html#LanguageTool", null ],
      [ "LibreOfficeKit", "a02539.html#LibreOfficeKit", null ],
      [ "l10ntools", "a02539.html#l10ntools", null ],
      [ "Math", "a02539.html#Math", null ],
      [ "package", "a02539.html#package", null ],
      [ "pyuno", "a02539.html#pyuno", null ],
      [ "rustuno", "a02539.html#rustuno", null ],
      [ "sdext", "a02539.html#sdext", null ],
      [ "sfx", "a02539.html#sfx", null ],
      [ "slideshow", "a02539.html#slideshow", null ],
      [ "sot", "a02539.html#sot", null ],
      [ "svl", "a02539.html#svl", null ],
      [ "svtools", "a02539.html#svtools", null ],
      [ "svx", "a02539.html#svx", null ],
      [ "toolkit", "a02539.html#toolkit", null ],
      [ "tools", "a02539.html#tools", null ],
      [ "ucb", "a02539.html#ucb", null ],
      [ "unotools", "a02539.html#unotools", null ],
      [ "URE", "a02539.html#URE", null ],
      [ "sax", "a02539.html#sax", null ],
      [ "stoc", "a02539.html#stoc", null ],
      [ "VCL", "a02539.html#VCL", null ],
      [ "winaccessibility", "a02539.html#winaccessibility", null ],
      [ "Writer", "a02539.html#Writer", null ],
      [ "writerfilter", "a02539.html#writerfilter", null ],
      [ "writerperfect", "a02539.html#writerperfect", null ],
      [ "xmloff", "a02539.html#xmloff", null ],
      [ "xmlsecurity", "a02539.html#xmlsecurity", null ],
      [ "xmlscript", "a02539.html#xmlscript", null ],
      [ "dbaccess", "a02539.html#dbaccess", null ],
      [ "avmedia", "a02539.html#avmedia", null ],
      [ "other", "a02539.html#other", null ]
    ] ],
    [ "Basic logging functionality.", "a02540.html", null ],
    [ "Deprecated List", "a00518.html", null ],
    [ "Todo List", "a00519.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"a00008.html",
"a00083.html#ad81bc3680b7f99be0a1a1482a38e533c",
"a00125.html",
"a00152.html#ab7f49d173ed996548a2185a7aace26d9",
"a00188.html#abff7d95dcd969cbdf1ec32c800faffcb",
"a00236.html#a026df9a7dc5a3644a22d575407836263a05470b4467b01d015082c4d7505858f1",
"a00287.html#a26ca5ffc96b32c3be3b42ef51436b17f",
"a00515.html#ac3f10d1dde9a631a2df769c9eefd1fd3",
"a00537.html#a36808dda29a2ec49670b0b872e75fa13",
"a00606.html",
"a00662.html#ad74a3c73403419e46c7a92870f7e9b10",
"a00734.html#aed0b013ab18b23707b7b2788ef4fdd5e",
"a00754.html#a6622d70ef347f46d155b4a49bf68752c",
"a00774.html#ae2e12b95c2df5b6cab62104982151c7eaca7db22a5e31421a7e2306060167f419",
"a00818.html#a10b27a9d38e4e5c73c477259202cd4fe",
"a00858.html#ac85ef2864e747240e53f3db9df1ec4c3",
"a00954.html#a2cf4f115042fda34f5edb545a8e96878",
"a01010.html#a56de184bc83af0a21d396de4c54f405a",
"a01098.html#adbc203e7235e02bf44917c243de7b126",
"a01218.html#adaaa168244b4bad4afb2a90d090a0cef",
"a01338.html",
"a01442.html#aad0b4c56e092bbc1a45ca7d14a2a9b23",
"a01554.html#ae8127f1b5406ffbc976ca7a5cd9283b1",
"a01674.html#a2b55425d3c8e0fac91bab01a7a9d12df",
"a01778.html#adb6444322d514f4cb23a4afd52df2605",
"a01874.html#a80a384915e2985753f7bdbb1c9195faa",
"a01930.html#ab3eaf4a3b6d6e699c6feb2820069c0ff",
"a02539.html#URE",
"globals_func_o.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
